@@ -167,7 +167,9 @@ where
     type Map = Self;
     type Struct = Self;
     type Tuple = Self;
-    type Variant = Self;
+    type StructVariant = Self;
+    type TupleVariant = Self;
+    type UnitVariant = Self;
 
     #[inline]
     fn expecting(&self, _: &mut fmt::Formatter<'_>) -> fmt::Result {
